@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -101,7 +101,7 @@ public final class Utility {
             // Keep interrupted status
             Thread.currentThread().interrupt();
         } catch (final ExecutionException e) {
-            final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Utility.class);
+            final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Utility.class));
             LOG.error(e.getMessage(), e);
         }
         return TimeZone.getTimeZone(ID);
@@ -137,8 +137,8 @@ public final class Utility {
      * @return The fields with required field (possibly appended)
      */
     public static int[] checkForRequiredField(final int[] fields, final int requiredField) {
-        for (int i = 0; i < fields.length; i++) {
-            if (requiredField == fields[i]) {
+        for (final int field : fields) {
+            if (requiredField == field) {
                 /*
                  * Found
                  */
