@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,8 +55,8 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
+import java.util.Set;
 import java.util.regex.Pattern;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -83,7 +83,6 @@ import com.openexchange.user.json.filter.UserCensorship;
 public abstract class AbstractUserAction implements AJAXActionService {
 
     private static final String ALL = "*";
-
     /**
      * Initializes a new {@link AbstractUserAction}.
      */
@@ -219,6 +218,22 @@ public abstract class AbstractUserAction implements AJAXActionService {
         }
     }
 
+    /**
+     * Parses specified parameter into an <code>int</code>.
+     * 
+     * @param parameterName The parameter name
+     * @param request The request
+     * @return The parsed <code>int</code> value
+     * @throws AjaxException If parameter is not present or invalid in given request
+     */
+    protected static String checkStringParameter(final String parameterName, final AJAXRequestData request) throws AjaxException {
+        String tmp = request.getParameter(parameterName);
+        if (null == tmp) {
+            throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, parameterName);
+        }
+        return tmp.trim();
+    }
+
     private static final Pattern PAT = Pattern.compile(" *, *");
     
     private static final ContactCensorship DO_NOTHING_CENSORSHIP = new DoNothingCensorship();
@@ -268,10 +283,10 @@ public abstract class AbstractUserAction implements AJAXActionService {
         return columns;
     }
     
-    protected static void censor(ServerSession session, Contact...contacts) throws OXException {
-        ContactCensorship censorship = getContactCensorship(session);
+    protected static void censor(final ServerSession session, final Contact...contacts) throws OXException {
+        final ContactCensorship censorship = getContactCensorship(session);
         
-        for (Contact contact : contacts) {
+        for (final Contact contact : contacts) {
             if(contact.getInternalUserId() == session.getUserId()) {
                 continue;
             }
@@ -280,8 +295,8 @@ public abstract class AbstractUserAction implements AJAXActionService {
         
     }
     
-    protected static void censor(ServerSession session, User[] user) throws OXException {
-        UserCensorship censorship = getUserCensorship(session);
+    protected static void censor(final ServerSession session, final User[] user) throws OXException {
+        final UserCensorship censorship = getUserCensorship(session);
         for(int i = 0; i < user.length; i++) {
             if(user[i].getId() == session.getUserId()) {
                 continue;
@@ -290,24 +305,24 @@ public abstract class AbstractUserAction implements AJAXActionService {
         }
     }
     
-    protected static User censor(ServerSession session, User user) throws OXException {
+    protected static User censor(final ServerSession session, final User user) throws OXException {
         if(user.getId() == session.getUserId()) {
             return user;
         }
-        UserCensorship censorship = getUserCensorship(session);
+        final UserCensorship censorship = getUserCensorship(session);
         return censorship.censor(user);
     }
     
 
 
-    protected static ContactCensorship getContactCensorship(ServerSession session) throws OXException {
+    protected static ContactCensorship getContactCensorship(final ServerSession session) throws OXException {
         if( canSeeGlobalAddressBook(session) ) {
             return DO_NOTHING_CENSORSHIP;
         }
         return NO_GLOBAL_ADDRESSBOOK_CENSORSHIP;
     }
     
-    protected static UserCensorship getUserCensorship(ServerSession session) throws OXException {
+    protected static UserCensorship getUserCensorship(final ServerSession session) throws OXException {
          if( canSeeGlobalAddressBook(session) ) {
              return DO_NOTHING_USER_CENSORSHIP;
          }
@@ -315,9 +330,9 @@ public abstract class AbstractUserAction implements AJAXActionService {
          return NO_GLOBAL_ADDRESSBOOK_USER_CENSORSHIP;
     }
 
-    private static boolean canSeeGlobalAddressBook(ServerSession session) throws OXException {
-        OXFolderAccess folderAccess = new OXFolderAccess(session.getContext());
-        EffectivePermission folderPermission = folderAccess.getFolderPermission(FolderObject.SYSTEM_LDAP_FOLDER_ID, session.getUserId(), session.getUserConfiguration());
+    private static boolean canSeeGlobalAddressBook(final ServerSession session) throws OXException {
+        final OXFolderAccess folderAccess = new OXFolderAccess(session.getContext());
+        final EffectivePermission folderPermission = folderAccess.getFolderPermission(FolderObject.SYSTEM_LDAP_FOLDER_ID, session.getUserId(), session.getUserConfiguration());
         return folderPermission.canReadAllObjects() && folderPermission.isFolderVisible();
     }
 }
