@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -87,7 +87,13 @@ public final class GetAction extends AbstractUserAction {
         /*
          * Parse parameters
          */
-        final int userId = checkIntParameter("id", request);
+        String idParam = request.getParameter("id");
+        int userId;
+        if(null == idParam) {
+            userId = session.getUserId();
+        } else {
+            userId = checkIntParameter("id", request);
+        }
         /*
          * Obtain user from user service
          */
