@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.user.json.actions;
 
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Date;
@@ -65,7 +66,9 @@ import com.openexchange.api2.ContactInterfaceFactory;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.UserService;
@@ -106,14 +109,21 @@ public final class ListAction extends AbstractUserAction {
              */
             final int[] userIdArray;
             {
-                final JSONArray jsonArray = (JSONArray) request.getData();
+                final JSONArray jsonArray = getJsonArrayFromData(request.getData());
                 if (null == jsonArray) {
                     throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, "data");
                 }
                 final int len = jsonArray.length();
+                if (0 == len) {
+                    return new AJAXRequestResult(new JSONArray(), null);
+                }
                 userIdArray = new int[len];
                 for (int a = 0; a < len; a++) {
-                    userIdArray[a] = jsonArray.getInt(a);
+                    if (jsonArray.isNull(a)) {
+                        userIdArray[a] = session.getUserId();
+                    } else {
+                        userIdArray[a] = jsonArray.getInt(a);
+                    }
                 }
             }
             final int[] columns = parseIntArrayParameter(AJAXServlet.PARAMETER_COLUMNS, request);
@@ -133,13 +143,47 @@ public final class ListAction extends AbstractUserAction {
             /*
              * Get users/contacts
              */
-            final User[] users = new User[userIdArray.length];
-            final Contact[] contacts = new Contact[userIdArray.length];
-            for (int i = 0; i < users.length; i++) {
-                final int userId = userIdArray[i];
-                users[i] = userService.getUser(userId, session.getContext());
-                contacts[i] = contactInterface.getUserById(userId, false);
+            User[] users;
+            try {
+                users = userService.getUser(session.getContext(), userIdArray);
+            } catch (final UserException e) {
+                if (UserException.Code.USER_NOT_FOUND.getDetailNumber() != e.getDetailNumber()) {
+                    throw e;
+                }
+                final Context context = session.getContext();
+                {
+                    final Object[] excArgs = e.getMessageArgs();
+                    if (excArgs != null && excArgs.length >= 2) {
+                        try {
+                            userService.invalidateUser(context, ((Integer) excArgs[0]).intValue());
+                        } catch (final Exception ignore) {
+                            // Ignore
+                        }
+                    } else {
+                        for (final int userId : userIdArray) {
+                            try {
+                                userService.invalidateUser(context, userId);
+                            } catch (final Exception ignore) {
+                                // Ignore
+                            }
+                        }
+                    }
+                }
+                // Load one-by-one
+                final int length = userIdArray.length;
+                final List<User> list = new ArrayList<User>(length);
+                for (int i = 0; i < length; i++) {
+                    try {
+                        list.add(userService.getUser(userIdArray[i], context));
+                    } catch (final UserException ue) {
+                        if (UserException.Code.USER_NOT_FOUND.getDetailNumber() != ue.getDetailNumber()) {
+                            throw ue;
+                        }
+                    }
+                }
+                users = list.toArray(new User[list.size()]);
             }
+            final Contact[] contacts = contactInterface.getUsersById(userIdArray, false);
             /*
              * Determine max. last-modified time stamp
              */
@@ -165,4 +209,39 @@ public final class ListAction extends AbstractUserAction {
         }
     }
 
+    private JSONArray getJsonArrayFromData(final Object data) {
+        if (null == data) {
+            return new JSONArray();
+        }
+        if (data instanceof JSONArray) {
+            return (JSONArray) data;
+        }
+        final String sData = data.toString().trim();
+        if (isEmpty(sData)) {
+            return new JSONArray();
+        }
+        if ('[' == sData.charAt(0)) {
+            try {
+                return new JSONArray(sData);
+            } catch (final JSONException e) {
+                // Ignore
+            }
+        }
+        final JSONArray ret = new JSONArray();
+        ret.put(sData);
+        return ret;
+    }
+
+    private boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
 }
