@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -123,6 +123,7 @@ public final class SearchAction extends AbstractUserAction {
             final int[] columns = parseIntArrayParameter(AJAXServlet.PARAMETER_COLUMNS, request);
             final int orderBy = parseIntParameter(AJAXServlet.PARAMETER_SORT, request);
             final Order order = OrderFields.parse(request.getParameter(AJAXServlet.PARAMETER_ORDER));
+            final String collation = request.getParameter(AJAXServlet.PARAMETER_COLLATION);
             final String timeZoneId = request.getParameter(AJAXServlet.PARAMETER_TIMEZONE);
             /*
              * Get remaining parameters
@@ -177,13 +178,13 @@ public final class SearchAction extends AbstractUserAction {
                 final ContactSearchMultiplexer multiplexer =
                     new ContactSearchMultiplexer(ServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
                 final int[] checkedCols = checkForRequiredField(columns, UserField.INTERNAL_USERID.getColumn());
-                it = multiplexer.extendedSearch(session, searchObj, orderBy, order, checkedCols);
+                it = multiplexer.extendedSearch(session, searchObj, orderBy, order, collation, checkedCols);
             } else {
                 // Get contact iterator with dummy search fields
                 final ContactSearchMultiplexer multiplexer =
                     new ContactSearchMultiplexer(ServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
                 final int[] checkedCols = checkForRequiredField(columns, UserField.INTERNAL_USERID.getColumn());
-                it = multiplexer.extendedSearch(session, searchObj, UserField.DISPLAY_NAME.getColumn(), Order.ASCENDING, checkedCols);
+                it = multiplexer.extendedSearch(session, searchObj, UserField.DISPLAY_NAME.getColumn(), Order.ASCENDING, collation, checkedCols);
             }
             /*
              * Collect contacts from iterator
@@ -199,7 +200,7 @@ public final class SearchAction extends AbstractUserAction {
                 try {
                     it.close();
                 } catch (final Exception e) {
-                    final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(SearchAction.class);
+                    final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(SearchAction.class));
                     LOG.error(e.getMessage(), e);
                 }
             }
@@ -214,10 +215,8 @@ public final class SearchAction extends AbstractUserAction {
             /*
              * TODO: Sort users if a user field was denoted by sort field
              */
-            /*
-             * Determine max. last-modified time stamp
-             */
-            Date lastModified = contacts[0].getLastModified();
+            // Determine max. last-modified time stamp
+            Date lastModified = new Date(0);
             for (int i = 1; i < contacts.length; i++) {
                 final Date lm = contacts[i].getLastModified();
                 if (lastModified.before(lm)) {
