@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -117,6 +117,8 @@ public final class UserActionFactory implements AJAXActionServiceFactory {
         tmp.put(AllAction.ACTION, new AllAction());
         tmp.put(SearchAction.ACTION, new SearchAction());
         tmp.put(UpdateAction.ACTION, new UpdateAction());
+        tmp.put(GetAttributeAction.ACTION, new GetAttributeAction());
+        tmp.put(SetAttributeAction.ACTION, new SetAttributeAction());
         return Collections.unmodifiableMap(tmp);
     }
 
