@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -623,8 +623,8 @@ public enum UserField {
 
     public static final EnumSet<UserField> UNPROTECTED_FIELDS = EnumSet.of(ID, DISPLAY_NAME, FIRST_NAME, LAST_NAME, SECOND_NAME, SUFFIX);
     
-    public static boolean isProtected(int field) {
-        for (UserField uf : UNPROTECTED_FIELDS) {
+    public static boolean isProtected(final int field) {
+        for (final UserField uf : UNPROTECTED_FIELDS) {
             if(uf.getColumn() == field) {
                 return false;
             }
