@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -87,9 +87,9 @@ public final class ServletRegisterer implements ServiceTrackerCustomizer {
             service.registerServlet(com.openexchange.user.json.Constants.SERVLET_PATH, new UserServlet(), null, null);
             return service;
         } catch (final ServletException e) {
-            LogFactory.getLog(ServletRegisterer.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletRegisterer.class)).error(e.getMessage(), e);
         } catch (final NamespaceException e) {
-            LogFactory.getLog(ServletRegisterer.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletRegisterer.class)).error(e.getMessage(), e);
         }
         // Nothing to track on error
         return null;
