@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,15 +49,15 @@
 
 package com.openexchange.user.json.writer;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
+import java.util.Set;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -66,6 +66,7 @@ import com.openexchange.groupware.container.DistributionListEntryObject;
 import com.openexchange.groupware.container.LinkEntryObject;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.tools.servlet.AjaxException;
+import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.user.json.Utility;
 import com.openexchange.user.json.field.DistributionListField;
 import com.openexchange.user.json.field.UserField;
@@ -77,7 +78,7 @@ import com.openexchange.user.json.field.UserField;
  */
 public final class UserWriter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UserWriter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UserWriter.class));
 
     private static final boolean WARN = LOG.isWarnEnabled();
 
@@ -717,21 +718,21 @@ public final class UserWriter {
 
             public void writeField(final JSONValuePutter jsonPutter, final User user, final Contact contact) throws JSONException {
                 final String s = contact.getEmail1();
-                jsonPutter.put(UserField.EMAIL1.getName(), null == s ? JSONObject.NULL : s);
+                jsonPutter.put(UserField.EMAIL1.getName(), null == s ? JSONObject.NULL : Tools.toIDN(s));
             }
         });
         m.put(UserField.EMAIL2.getColumn(), new UserFieldWriter() {
 
             public void writeField(final JSONValuePutter jsonPutter, final User user, final Contact contact) throws JSONException {
                 final String s = contact.getEmail2();
-                jsonPutter.put(UserField.EMAIL2.getName(), null == s ? JSONObject.NULL : s);
+                jsonPutter.put(UserField.EMAIL2.getName(), null == s ? JSONObject.NULL : Tools.toIDN(s));
             }
         });
         m.put(UserField.EMAIL3.getColumn(), new UserFieldWriter() {
 
             public void writeField(final JSONValuePutter jsonPutter, final User user, final Contact contact) throws JSONException {
                 final String s = contact.getEmail3();
-                jsonPutter.put(UserField.EMAIL3.getName(), null == s ? JSONObject.NULL : s);
+                jsonPutter.put(UserField.EMAIL3.getName(), null == s ? JSONObject.NULL : Tools.toIDN(s));
             }
         });
         m.put(UserField.TELEPHONE_ISDN.getColumn(), new UserFieldWriter() {
@@ -967,9 +968,8 @@ public final class UserWriter {
                 } else {
                     final JSONArray jsonArray = new JSONArray();
 
-                    for (int a = 0; a < links.length; a++) {
+                    for (final LinkEntryObject link : links) {
                         final JSONObject jsonLinkObject = new JSONObject();
-                        final LinkEntryObject link = links[a];
                         if (link.containsLinkID()) {
                             jsonLinkObject.put(UserField.ID.getName(), link.getLinkID());
                         }
@@ -988,9 +988,8 @@ public final class UserWriter {
                     jsonPutter.put(UserField.DISTRIBUTIONLIST.getName(), JSONObject.NULL);
                 } else {
                     final JSONArray jsonArray = new JSONArray();
-                    for (int a = 0; a < distributionList.length; a++) {
+                    for (final DistributionListEntryObject listEntry : distributionList) {
                         final JSONObject jsonDListObj = new JSONObject();
-                        final DistributionListEntryObject listEntry = distributionList[a];
                         /*
                          * Write entry to new JSON object
                          */
@@ -1202,11 +1201,11 @@ public final class UserWriter {
     public static JSONArray writeSingle2Array(final int[] fields, final Map<String, List<String>> attributeParameters, final User user, final Contact contact, final String timeZoneId) throws AjaxException {
         final int[] cols = null == fields ? ALL_FIELDS : fields;
         final List<UserFieldWriter> ufws = new ArrayList<UserFieldWriter>(cols.length + AVERAGE_ATTR_PARAMS_SIZE);
-        for (int i = 0; i < cols.length; i++) {
-            UserFieldWriter ufw = getUserFieldWriter(cols[i], timeZoneId);
+        for (final int col : cols) {
+            UserFieldWriter ufw = getUserFieldWriter(col, timeZoneId);
             if (null == ufw) {
                 if (WARN) {
-                    LOG.warn("Unknown field: " + cols[i], new Throwable());
+                    LOG.warn("Unknown field: " + col, new Throwable());
                 }
                 ufw = UNKNOWN_FIELD_FFW;
             }
@@ -1239,11 +1238,11 @@ public final class UserWriter {
     public static JSONArray writeMultiple2Array(final int[] fields, final Map<String, List<String>> attributeParameters, final User[] users, final Contact[] contacts, final String timeZoneId) throws AjaxException {
         final int[] cols = null == fields ? ALL_FIELDS : fields;
         final List<UserFieldWriter> ufws = new ArrayList<UserFieldWriter>(cols.length + AVERAGE_ATTR_PARAMS_SIZE);
-        for (int i = 0; i < cols.length; i++) {
-            UserFieldWriter ufw = getUserFieldWriter(cols[i], timeZoneId);
+        for (final int col : cols) {
+            UserFieldWriter ufw = getUserFieldWriter(col, timeZoneId);
             if (null == ufw) {
                 if (WARN) {
-                    LOG.warn("Unknown field: " + cols[i], new Throwable());
+                    LOG.warn("Unknown field: " + col, new Throwable());
                 }
                 ufw = UNKNOWN_FIELD_FFW;
             }
@@ -1281,11 +1280,11 @@ public final class UserWriter {
     public static JSONObject writeSingle2Object(final int[] fields, final Map<String, List<String>> attributeParameters, final User user, final Contact contact, final String timeZoneId) throws AjaxException {
         final int[] cols = null == fields ? ALL_FIELDS : fields;
         final List<UserFieldWriter> ufws = new ArrayList<UserFieldWriter>(cols.length + AVERAGE_ATTR_PARAMS_SIZE);
-        for (int i = 0; i < cols.length; i++) {
-            UserFieldWriter ufw = getUserFieldWriter(cols[i], timeZoneId);
+        for (final int col : cols) {
+            UserFieldWriter ufw = getUserFieldWriter(col, timeZoneId);
             if (null == ufw) {
                 if (WARN) {
-                    LOG.warn("Unknown field: " + cols[i], new Throwable());
+                    LOG.warn("Unknown field: " + col, new Throwable());
                 }
                 ufw = UNKNOWN_FIELD_FFW;
             }
@@ -1318,11 +1317,11 @@ public final class UserWriter {
     public static JSONArray writeMultiple2Object(final int[] fields, final Map<String, List<String>> attributeParameters, final User[] users, final Contact[] contacts, final String timeZoneId) throws AjaxException {
         final int[] cols = null == fields ? ALL_FIELDS : fields;
         final List<UserFieldWriter> ufws = new ArrayList<UserFieldWriter>(cols.length + AVERAGE_ATTR_PARAMS_SIZE);
-        for (int i = 0; i < cols.length; i++) {
-            UserFieldWriter ufw = getUserFieldWriter(cols[i], timeZoneId);
+        for (final int col : cols) {
+            UserFieldWriter ufw = getUserFieldWriter(col, timeZoneId);
             if (null == ufw) {
                 if (WARN) {
-                    LOG.warn("Unknown field: " + cols[i], new Throwable());
+                    LOG.warn("Unknown field: " + col, new Throwable());
                 }
                 ufw = UNKNOWN_FIELD_FFW;
             }
